==> abi-0.7.9.tar.gz: abi-0.7.9/src/wp/ap/xp/ap_Menu_LabelSet_sv-SE.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Swedish translations provided by Henrik Berg <henrik@lansen.se>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(sv,SE,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Arkiv",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Nytt", 			"Skapar ett nytt tomt dokument")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&ppna",			"ppnar ett befintligt dokument")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"St&ng", 			"Stnger dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Spara", 			"Sparar dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Spara so&m", 		"Sparar dokumentet med ett nytt namn")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"Utskriftsforma&t", "Change the printing options")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"Skriv &ut",		"Skriver ut allt eller delar av dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Avsluta", 		"Stnger programmets alla fnster, och avslutar")

	MenuLabel(AP_MENU_ID_EDIT,				"&Redigera",		NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&ngra",			"ngra inmatningen")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"&Upprepa",			"Upprepa fregende ngrade inmatning")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Klipp ut",		"Klipper ut markeringen och placerar den i Urklippet")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"K&opiera",			"Kopierar markeringen och placerar den i Urklippet")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"K&listra in",		"Infogar innehllet i Urklipp")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Radera",			"Raderar markeringen")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"&Markera allt",	"Markerar hela dokumentet")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Sk",				"Sker efter angiven text")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"&Erstt",			"Erstter angiven text med annan text")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&G till",			"G till en ny plats i dokumentet")
     
	MenuLabel(AP_MENU_ID_VIEW,				"Vi&sa",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Verktygsflt",	NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",		"Visar eller dljer verktygsfltet Standard")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formatera",		"Visar eller dljer verktygsfltet Formatera")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Linjal",			"Visar eller dljer linjalen")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"S&tatusrad",		"Visar eller dljer statusraden")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"&Visa alla",		"Visar alla icke utskrivbara tecken")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Sidhuvud och sidfot",	"Redigera text vid huvud eller fot p varje sida")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zooma",			"Minska eller frstora visningen av dokumentet")

	MenuLabel(AP_MENU_ID_INSERT,			"&Infoga",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Brytning",		"Infogar sid-, spalt-, eller styckebrytning")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"Sidn&ummer",		"Infogar sidnumrering som uppdateras automatisk")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"Datum och &tid",	"Infogar dagens datum och/eller tid")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Flt",			"Infogar ett automatiskt flt")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"Sy&mbol",			"Infogar en symbol eller annat specialtecken")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"&Bildobjekt",		"Infogar en ny bild frn en annan fil")

	MenuLabel(AP_MENU_ID_FORMAT,			"Forma&t",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"T&ecken",			"Vljer teckensnitt fr aktuell markering")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Stycke",			"Formaterar aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"Punkter och &numrering",	"Infogar eller ndrar punkter och numrering fr markerade stycken")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Kantlinjer och f&yllning",	"Infogar kantlinjer och fyllning till aktuell markering")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"S&palter",			"ndrar antalet spalter")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"Format&mall",		"Define or apply style for the selection")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabbar",			"Stller in tabbar")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Fet",				"Gr aktuell markering fetstil (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kursiv",			"Gr aktuell markering kursiv (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Understruken",	"Gr aktuell markering understruken (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"&verstruken",		"Gr aktuell markering verstruken (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"&Genomstruken",	"Gr aktuell markering genomstruken (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,	"Upp&hjd",			"Gr aktuell markering upphjd (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"Neds&nkt",		"Gr aktuell markering nedsnkt (vxlande)")

	MenuLabel(AP_MENU_ID_TOOLS,				"&Verktyg",			NULL)
	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Stavning",		"Kontroller stavningen i dokumentet")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"&Ord statistik",	"Rkna antal ord, rader, paragrafer, osv i dokumentet")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Alternativ",		"Anger alternativ")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Justering",		NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Vnster",			"Vnsterjustera aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Centrerat",		"Centrera aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Hger",			"Hgerjustera aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Marginaler",		"Marginaljustera aktuellt eller markerade stycken")

	MenuLabel(AP_MENU_ID_WINDOW,			"F&nster",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Nytt fnster",	"ppnar ett annat fnster fr dokumentet")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Fler fnster",	"Visa hela lista med fnster")

	MenuLabel(AP_MENU_ID_HELP,				"&Hjlp",			NULL)
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Om %s",			"Visar programinformation, versionsnummer, och copyright")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"&Ignorera alla", 	"Ignorera alla frekomster av detta ord i dokumentet")
	MenuLabel(AP_MENU_ID_SPELL_ADD,			"&Lgg till", 		"Lgg till detta ord till den egna ordlistan")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_Menu_LabelSet_sv-SE.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Swedish translations provided by Henrik Berg <henrik@lansen.se>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(sv,SE,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Arkiv",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Nytt", 			"Skapar ett nytt tomt dokument")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&ppna",			"ppnar ett befintligt dokument")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"St&ng", 			"Stnger dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Spara", 			"Sparar dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Spara so&m", 		"Sparar dokumentet med ett nytt namn")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"Utskriftsforma&t", "Change the printing options")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"Skriv &ut",		"Skriver ut allt eller delar av dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"ppnar detta dokumentet")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Avsluta", 		"Stnger programmets alla fnster, och avslutar")

	MenuLabel(AP_MENU_ID_EDIT,				"&Redigera",		NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&ngra",			"ngra inmatningen")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"&Upprepa",			"Upprepa fregende ngrade inmatning")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Klipp ut",		"Klipper ut markeringen och placerar den i Urklippet")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"K&opiera",			"Kopierar markeringen och placerar den i Urklippet")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"K&listra in",		"Infogar innehllet i Urklipp")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Radera",			"Raderar markeringen")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"&Markera allt",	"Markerar hela dokumentet")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Sk",				"Sker efter angiven text")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"&Erstt",			"Erstter angiven text med annan text")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&G till",			"G till en ny plats i dokumentet")
     
	MenuLabel(AP_MENU_ID_VIEW,				"Vi&sa",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Verktygsflt",	NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",		"Visar eller dljer verktygsfltet Standard")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formatera",		"Visar eller dljer verktygsfltet Formatera")
	MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,		"&Extra",			"Visar eller dljer verktygsfltet Extra")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Linjal",			"Visar eller dljer linjalen")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"S&tatusrad",		"Visar eller dljer statusraden")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"&Visa alla",		"Visar alla icke utskrivbara tecken")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Sidhuvud och sidfot",	"Redigera text vid huvud eller fot p varje sida")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zooma",			"Minska eller frstora visningen av dokumentet")

	MenuLabel(AP_MENU_ID_INSERT,			"&Infoga",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Brytning",		"Infogar sid-, spalt-, eller styckebrytning")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"Sidn&ummer",		"Infogar sidnumrering som uppdateras automatisk")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"Datum och &tid",	"Infogar dagens datum och/eller tid")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Flt",			"Infogar ett automatiskt flt")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"Sy&mbol",			"Infogar en symbol eller annat specialtecken")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"&Bildobjekt",		"Infogar en ny bild frn en annan fil")

	MenuLabel(AP_MENU_ID_FORMAT,			"Forma&t",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"T&ecken",			"Vljer teckensnitt fr aktuell markering")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Stycke",			"Formaterar aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"Punkter och &numrering",	"Infogar eller ndrar punkter och numrering fr markerade stycken")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Kantlinjer och f&yllning",	"Infogar kantlinjer och fyllning till aktuell markering")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"S&palter",			"ndrar antalet spalter")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"Format&mall",		"Define or apply style for the selection")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabbar",			"Stller in tabbar")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Fet",				"Gr aktuell markering fetstil (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kursiv",			"Gr aktuell markering kursiv (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Understruken",	"Gr aktuell markering understruken (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"&verstruken",		"Gr aktuell markering verstruken (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"&Genomstruken",	"Gr aktuell markering genomstruken (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,	"Upp&hjd",			"Gr aktuell markering upphjd (vxlande)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"Neds&nkt",		"Gr aktuell markering nedsnkt (vxlande)")

	MenuLabel(AP_MENU_ID_TOOLS,				"&Verktyg",			NULL)
	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Stavning",		"Kontroller stavningen i dokumentet")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"&Ord statistik",	"Rkna antal ord, rader, paragrafer, osv i dokumentet")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Alternativ",		"Anger alternativ")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Justering",		NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Vnster",			"Vnsterjustera aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Centrerat",		"Centrera aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Hger",			"Hgerjustera aktuellt eller markerade stycken")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Marginaler",		"Marginaljustera aktuellt eller markerade stycken")

	MenuLabel(AP_MENU_ID_WINDOW,			"F&nster",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Nytt fnster",	"ppnar ett annat fnster fr dokumentet")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Aktiverar detta fnstret")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Fler fnster",	"Visa hela lista med fnster")

	MenuLabel(AP_MENU_ID_HELP,				"&Hjlp",			NULL)
	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"Hjlp &Contents",	"Visar hjlp Contents")
	MenuLabel(AP_MENU_ID_HELP_INDEX,		"Hjlp &index",		"Visar hjlp Index")
	MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"Visa &version",	"Visar programmets versionsnummer")
	MenuLabel(AP_MENU_ID_HELP_SEARCH,		"&Search for Help",	"Sker i hjlpen")
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Om %s",			"Visar programinformation, versionsnummer, och copyright")
	MenuLabel(AP_MENU_ID_HELP_ABOUTOS,		"About &Open Source",	"Visar information om Open Source")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"ndrar till freslagen stavning")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"&Ignorera alla", 	"Ignorera alla frekomster av detta ord i dokumentet")
	MenuLabel(AP_MENU_ID_SPELL_ADD,			"&Lgg till", 		"Lgg till detta ord till den egna ordlistan")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()
